Index: pkg/http/test/utils.dart |
diff --git a/pkg/http/test/utils.dart b/pkg/http/test/utils.dart |
index c2ce9c449723dc70b45c0991a9ea16c5775e41e6..5c7cc0262dfcf90ea8566416608c32ca98e7f5bc 100644 |
--- a/pkg/http/test/utils.dart |
+++ b/pkg/http/test/utils.dart |
@@ -196,14 +196,14 @@ class _RedirectLimitExceededException extends TypeMatcher { |
item is RedirectLimitExceededException; |
} |
-/// A matcher for SocketIOExceptions. |
-const isSocketIOException = const _SocketIOException(); |
+/// A matcher for SocketExceptions. |
+const isSocketException = const _SocketException(); |
-/// A matcher for functions that throw SocketIOException. |
-const Matcher throwsSocketIOException = |
- const Throws(isSocketIOException); |
+/// A matcher for functions that throw SocketException. |
+const Matcher throwsSocketException = |
+ const Throws(isSocketException); |
-class _SocketIOException extends TypeMatcher { |
- const _SocketIOException() : super("SocketIOException"); |
- bool matches(item, MatchState matchState) => item is SocketIOException; |
+class _SocketException extends TypeMatcher { |
+ const _SocketException() : super("SocketException"); |
+ bool matches(item, MatchState matchState) => item is SocketException; |
} |